package info.aspirecn.cloud.yysj.controller;

import java.util.List;
import java.util.Map;

import javax.servlet.http.HttpServletResponse;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestHeader;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import info.aspirecn.cloud.yysj.entity.Produce;
import info.aspirecn.cloud.yysj.entity.ProduceList;
import info.aspirecn.cloud.yysj.entity.ResponseInfo;
import info.aspirecn.cloud.yysj.entity.UserProduce;
import info.aspirecn.cloud.yysj.service.ProductService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

/**
 * 产品列表、产品订购、订购产品数量等信息接口
 *
 * @author baizehui
 */
@Api(tags = "产品配置相关服务接口")
@ApiResponses({
        @ApiResponse(code = 200, message = "成功处理请求"),
        @ApiResponse(code = 400, message = "参数错误"),
        @ApiResponse(code = 401, message = "没有权限访问该服务"),
        @ApiResponse(code = 403, message = "权限不足无法访问该服务"),
        @ApiResponse(code = 404, message = "未发现该微服务"),
        @ApiResponse(code = 500, message = "服务器内部错误")
})
@RestController
public class ProductController {
	
	@Autowired
    private ProductService productService;


//    @ApiOperation(value = "新建产品接口", notes = "新建产品接口。")
//    @PostMapping(value = "/saveProduce")
//    private ResponseInfo saveProduce(@RequestBody Produce produce){
//    	if (produce.getProduceName()== null&&"".equals(produce.getProduceName())) {
//    		return new ResponseInfo().setMessage("产品名称不能为空");
//		}
//    	if (produce.getSjjhId()== null&&produce.getSjjhId()== 0) {
//    		return new ResponseInfo().setMessage("数据交互产品id不能为空");
//		}
//    	if (produce.getType()== null&&produce.getType()== 0) {
//    		return new ResponseInfo().setMessage("产品类型不能为空");
//		}
//    	productService.saveProduce(produce);
//		return new ResponseInfo().setData("新建产品成功");
//    }
	
    @ApiOperation(value = "查询产品列表接口", notes = "获取产品列表接口。")
    @PostMapping("/productList")
    private ResponseInfo productList(HttpServletResponse response,@RequestHeader(required = false) String userId,@RequestBody ProduceList produceList){
    	  Map<String, Object>	map= productService.getProductList(userId,produceList.getProductName(),produceList.getPageNum(),produceList.getPageSize());
    	  Integer total = (Integer)map.get("total");
    	  response.addHeader("pageNum", Integer.toString(produceList.getPageNum()));
          response.addHeader("pageSize", Integer.toString(produceList.getPageSize()));
          response.addHeader("pageTotal",   Integer.toString(total%produceList.getPageSize() > 0 ? total/produceList.getPageSize()+1 : total/produceList.getPageSize()));
          response.addHeader("total",Integer.toString(total));
    	return new ResponseInfo().setData(map.get("dataList"));
    }
    
    @ApiOperation(value = "订购产品接口", notes = "订购产品接口。")
    @PostMapping(value = "/saveUserProduce")
    private ResponseInfo saveUserProduce(@RequestHeader(required = false) String userId,@RequestBody UserProduce userProduce){
    	if (userProduce.getProduceId()== null&&userProduce.getProduceId()== 0) {
    		 return new ResponseInfo().setMessage("产品id不能为空");
		}
    	if (userProduce.getProduceName()== null&&"".equals(userProduce.getProduceName())) {
    		 return new ResponseInfo().setMessage("产品名称不能为空");
		}
    	List<UserProduce> userProduceList=productService.queryUserProduce(userId,userProduce.getProduceId());
    	if (userProduceList.size()>=1) {
    		 return new ResponseInfo().setMessage("产品已订购");
		}
    	Integer saveUserProduce=productService.saveUserProduce(userId,userProduce);
    	if (saveUserProduce==1) {
    		return new ResponseInfo().setData("订购成功");
		}
		return new ResponseInfo().setData("订购失败");
    }
    
    @ApiOperation(value = "取消订购产品接口", notes = "取消订购产品接口。")
    @DeleteMapping(value = "/deleteUserProduce")
    private ResponseInfo deleteUserProduce(@RequestHeader(required = false) String userId,
    		@RequestParam(required = true) Integer produceId,
    		@RequestParam(required = true) String produceName){
    	if (userId== null&&"".equals(userId)) {
    		 return new ResponseInfo().setMessage("userId不能为空");
		}
    	if (produceId== null) {
    		 return new ResponseInfo().setMessage("产品id不能为空");
		}
    	if (produceName== null&&"".equals(produceName)) {
    		return new ResponseInfo().setMessage("产品名称不能为空");
		}
    	Integer deleteUserProduce=productService.deleteUserProduce(userId,produceId,produceName);
    	if (deleteUserProduce==1) {
    		return new ResponseInfo().setData("取消订购成功");
		}
		return new ResponseInfo().setData("取消订购失败");
    }
    
    
    @ApiOperation(value = "获取订购产品数量接口", notes = "获取订购产品数量接口。")
    @GetMapping("/getOrderProductCount")
    private ResponseInfo getOrderProductCount(@RequestHeader(required = false) String userId){
	    	if (userId== null&&"".equals(userId)) {
	   		 	return new ResponseInfo().setMessage("参数不能为空");
			}
	    	Map<String, Integer> orderProductCount=productService.getOrderProductCount(userId);
    	  return new ResponseInfo().setData(orderProductCount);
    }
    
     
    @ApiOperation(value = "获取产品名称列表接口", notes = "获取产品列表接口。")
    @GetMapping("/getProductNameList")
    private ResponseInfo getProductNameList(){
	    	List<Produce> list=productService.getProductNameList();
    	  return new ResponseInfo().setData(list);
    }
    
    
}
